# biomodules: 生物信息模块

## 通用模块

1. `merge_dir.MergeDir`: 给定一个输入文件夹和一个输出文件，把该文件夹下的所有文件合并到该文件中。

## 序列相关

1. `seq.fastq2fasta.Fastq2Fasta`：fastq转fasta。

## 预处理模块

1. `preprocessing.fastqc.Fastqc`: 使用fastqc进行质量控制。
